Function rustduino::atmega2560p::com::usart::println_set_baud [−][src]
pub fn println_set_baud(data: &'static str, baud1: i64)
println() function for using USART according to default used values and user defined value of baud rate. Transmitter mode is first enabled for the default usart. Then the function takes the usart and initializes it with user defined. Then the string given by the user is transmitted through the USART.
Arguments
data- a string object, which is to be transmitted using USART.baud1- a i64, the baud rate of USART the user wants to set.