Function rustduino::atmega2560p::com::usart::println_string[][src]

pub fn println_string(data: &'static str)
Main println() function for using USART according to default used values. Transmitter mode is first enabled for the default usart. Then the function takes the usart and initializes it. Then the string given by the user is transmitted through the USART. This will be used to transmit string data.

Arguments

  • data - a string object, which is to be transmitted using USART.