Module rustduino::atmega2560p::com::usart_initialize[][src]

ATMEGA2560P has total of 4 USARTs. This is the file which contains functions for initializing USART in various modes. It has functions to check for the power reduction settings and start the USART in a user defined modes. After setting into a particular USART the functions are available to generate the clock with given frequency and baud rate. After which the frame for data tracking is set using various frame modes. See the section 22 of ATMEGA2560P datasheet.

Structs

This structure contains various registers needed to control usart communication through ATMEGA2560P device. Each USARTn ( n=0,1,2,3 ) is controlled by a total of 6 registers stored through this structure.

Contains the Usart as a Raw Pointer along with it’s name. This controls a USART as a object for careful implementation.

Enums

Selection of the Amount of Data Bits to be transferred or recieved through USART.

Selection of synchronous or asynchronous modes for USART.

Selection of which USART is to be used.

Selection of the parity mode for USART.

Selection of the clock parity mode.

Selection of number of stop bits for USART data.