Struct rustduino::atmega2560p::hal::pin::Pins [−][src]
#[repr(C, packed)]pub struct Pins { pub analog: [AnalogPin; 16], pub digital: [DigitalPin; 54], }
The ATMEGA2560P microcontroller IC has a total of 100 pins to configure the functioning of the microcontroller. Out of those 86 pins are set as I/O pins which are configured into 11 ports each controlling 8 pins except port G which controls 6 pins. All 8 pins of port F and K are Analog pins and total 54 digital pins are available and the rest 16 pins are for various other purposes. This structure declaration contains the space to control all the 86 pins in one memory mapped I/O.
Fields
analog: [AnalogPin; 16]digital: [DigitalPin; 54]