Function rustduino::atmega328p::hal::shift::shift_out [−][src]
pub fn shift_out(
datapin: usize,
clockpin: usize,
bit_order: BitOrder,
value: u8
)
Stores value in the Shift Register.
Arguments
datapin- a usize, containing the number of the digital pin from which data will be read.clockpin- a usize, containing the number of the digital pin from which clock source will be adjusted.bit_order- aBitOrderobject, to specify the order of bits in the shift register.value- a mutable u8, which will store the value which is to be written.